@@ -1,8 +1,6 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module contains the main object used to identify the coordination environments in a given structure.
 If you use this module, please cite the following:
@@ -11,6 +9,10 @@ Michael Goebel, Stephan Schenk, Peter Degelmann, Rute Andre, Robert Glaum, and G
 "Statistical analysis of coordination environments in oxides",
 Chem. Mater., 2017, 29 (19), pp 8346–8360,
 DOI: 10.1021/acs.chemmater.7b02766
+D. Waroquiers, J. George, M. Horton, S. Schenk, K. A. Persson, G.-M. Rignanese, X. Gonze, G. Hautier
+"ChemEnv: a fast and robust coordination environment identification tool",
+Acta Cryst. B 2020, 76, pp 683–695,
+DOI: 10.1107/S2052520620007994
 """
 
 __author__ = "David Waroquiers"
@@ -24,7 +26,6 @@ __date__ = "Feb 20, 2016"
 import itertools
 import logging
 import time
-from collections import OrderedDict
 from random import shuffle
 
 import numpy as np
@@ -151,9 +152,9 @@ class AbstractGeometry:
         String representation of the AbstractGeometry
         :return: String representation of the AbstractGeometry
         """
-        outs = ["\nAbstract Geometry with {n} points :".format(n=len(self.coords))]
+        outs = [f"\nAbstract Geometry with {len(self.coords)} points :"]
         for pp in self.coords:
-            outs.append("  {pp}".format(pp=pp))
+            outs.append(f"  {pp}")
         if self.centering_type == "standard":
             if self.include_central_site_in_centroid:
                 outs.append(
@@ -168,7 +169,7 @@ class AbstractGeometry:
                     " numbers >= 5 : {c}\n".format(c=self.centre)
                 )
         elif self.centering_type == "central_site":
-            outs.append("Points are referenced to the central site : {c}\n".format(c=self.centre))
+            outs.append(f"Points are referenced to the central site : {self.centre}\n")
         elif self.centering_type == "centroid":
             if self.include_central_site_in_centroid:
                 outs.append(
@@ -379,12 +380,18 @@ class LocalGeometryFinder:
         debug_level=None,
         plane_safe_permutations=False,
         only_symbols=None,
+        print_citation=False,
     ):
         """
-        Constructor for the LocalGeometryFinder, initializes the list of coordination geometries
-        :param permutations_safe_override: If set to True, all permutations are tested (very time-consuming for large
+
+        Args:
+            permutations_safe_override:  If set to True, all permutations are tested (very time-consuming for large
             coordination numbers!)
-        :param plane_ordering_override: If set to False, the ordering of the points in the plane is disabled
+            plane_ordering_override: If set to False, the ordering of the points in the plane is disabled
+            debug_level: decides the level of debugging
+            permutations_safe_override: Whether to use safe permutations.
+            only_symbols: Whether to restrict the list of environments to be identified.
+            print_citation: If True, the ChemEnv citation will be printed
         """
         self.allcg = AllCoordinationGeometries(
             permutations_safe_override=permutations_safe_override,
@@ -399,7 +406,8 @@ class LocalGeometryFinder:
             bva_distance_scale_factor=None,
             structure_refinement=self.STRUCTURE_REFINEMENT_NONE,
         )
-        print(chemenv_citations())
+        if print_citation:
+            print(chemenv_citations())
 
     def setup_parameters(
         self,
@@ -722,25 +730,20 @@ class LocalGeometryFinder:
             self.detailed_voronoi.separations = [None] * len(self.structure)
 
         # Loop on all the sites
-        for isite in range(len(self.structure)):
+        for isite, site in enumerate(self.structure):
             if isite not in sites_indices:
-                logging.debug(
-                    " ... in site #{:d}/{:d} ({}) : "
-                    "skipped".format(isite, len(self.structure), self.structure[isite].species_string)
-                )
+                logging.debug(f" ... in site #{isite:d}/{len(self.structure):d} ({site.species_string}) : skipped")
                 continue
             if breakit:
                 logging.debug(
                     " ... in site #{:d}/{:d} ({}) : "
-                    "skipped (timelimit)".format(isite, len(self.structure), self.structure[isite].species_string)
+                    "skipped (timelimit)".format(isite, len(self.structure), site.species_string)
                 )
                 continue
-            logging.debug(
-                " ... in site #{:d}/{:d} ({})".format(isite, len(self.structure), self.structure[isite].species_string)
-            )
+            logging.debug(f" ... in site #{isite:d}/{len(self.structure):d} ({site.species_string})")
             t1 = time.process_time()
             if optimization > 0:
-                self.detailed_voronoi.local_planes[isite] = OrderedDict()
+                self.detailed_voronoi.local_planes[isite] = {}
                 self.detailed_voronoi.separations[isite] = {}
             se.init_neighbors_sets(
                 isite=isite,
@@ -755,7 +758,7 @@ class LocalGeometryFinder:
                 if cn not in all_cns:
                     continue
                 for inb_set, nb_set in enumerate(nb_sets):
-                    logging.debug("    ... getting environments for nb_set ({:d}, {:d})".format(cn, inb_set))
+                    logging.debug(f"    ... getting environments for nb_set ({cn:d}, {inb_set:d})")
                     tnbset1 = time.process_time()
                     ce = self.update_nb_set_environments(
                         se=se,
@@ -776,7 +779,7 @@ class LocalGeometryFinder:
                             # Get possibly missing neighbors sets
                             if cg.neighbors_sets_hints is None:
                                 continue
-                            logging.debug('       ... getting hints from cg with mp_symbol "{}" ...'.format(cg_symbol))
+                            logging.debug(f'       ... getting hints from cg with mp_symbol "{cg_symbol}" ...')
                             hints_info = {
                                 "csm": cg_dict["symmetry_measure"],
                                 "nb_set": nb_set,
@@ -785,7 +788,7 @@ class LocalGeometryFinder:
                             for nb_sets_hints in cg.neighbors_sets_hints:
                                 suggested_nb_set_voronoi_indices = nb_sets_hints.hints(hints_info)
                                 for inew, new_nb_set_voronoi_indices in enumerate(suggested_nb_set_voronoi_indices):
-                                    logging.debug("           hint # {:d}".format(inew))
+                                    logging.debug(f"           hint # {inew:d}")
                                     new_nb_set = se.NeighborsSet(
                                         structure=se.structure,
                                         isite=isite,
@@ -854,9 +857,9 @@ class LocalGeometryFinder:
                 if time_left < 2.0 * max_time_one_site:
                     breakit = True
             max_time_one_site = max(max_time_one_site, t2 - t1)
-            logging.debug("    ... computed in {:.2f} seconds".format(t2 - t1))
+            logging.debug(f"    ... computed in {t2 - t1:.2f} seconds")
         time_end = time.process_time()
-        logging.debug("    ... compute_structure_environments ended in {:.2f} seconds".format(time_end - time_init))
+        logging.debug(f"    ... compute_structure_environments ended in {time_end - time_init:.2f} seconds")
         return se
 
     def update_nb_set_environments(self, se, isite, cn, inb_set, nb_set, recompute=False, optimization=None):
@@ -881,50 +884,50 @@ class LocalGeometryFinder:
         self.setup_local_geometry(isite, coords=neighb_coords, optimization=optimization)
         if optimization > 0:
             logging.debug("Getting StructureEnvironments with optimized algorithm")
-            nb_set.local_planes = OrderedDict()
+            nb_set.local_planes = {}
             nb_set.separations = {}
             cncgsm = self.get_coordination_symmetry_measures_optim(nb_set=nb_set, optimization=optimization)
         else:
             logging.debug("Getting StructureEnvironments with standard algorithm")
             cncgsm = self.get_coordination_symmetry_measures()
-        for cg in cncgsm:
+        for cg, d in cncgsm.items():
             other_csms = {
-                "csm_wocs_ctwocc": cncgsm[cg]["csm_wocs_ctwocc"],
-                "csm_wocs_ctwcc": cncgsm[cg]["csm_wocs_ctwcc"],
-                "csm_wocs_csc": cncgsm[cg]["csm_wocs_csc"],
-                "csm_wcs_ctwocc": cncgsm[cg]["csm_wcs_ctwocc"],
-                "csm_wcs_ctwcc": cncgsm[cg]["csm_wcs_ctwcc"],
-                "csm_wcs_csc": cncgsm[cg]["csm_wcs_csc"],
-                "rotation_matrix_wocs_ctwocc": cncgsm[cg]["rotation_matrix_wocs_ctwocc"],
-                "rotation_matrix_wocs_ctwcc": cncgsm[cg]["rotation_matrix_wocs_ctwcc"],
-                "rotation_matrix_wocs_csc": cncgsm[cg]["rotation_matrix_wocs_csc"],
-                "rotation_matrix_wcs_ctwocc": cncgsm[cg]["rotation_matrix_wcs_ctwocc"],
-                "rotation_matrix_wcs_ctwcc": cncgsm[cg]["rotation_matrix_wcs_ctwcc"],
-                "rotation_matrix_wcs_csc": cncgsm[cg]["rotation_matrix_wcs_csc"],
-                "scaling_factor_wocs_ctwocc": cncgsm[cg]["scaling_factor_wocs_ctwocc"],
-                "scaling_factor_wocs_ctwcc": cncgsm[cg]["scaling_factor_wocs_ctwcc"],
-                "scaling_factor_wocs_csc": cncgsm[cg]["scaling_factor_wocs_csc"],
-                "scaling_factor_wcs_ctwocc": cncgsm[cg]["scaling_factor_wcs_ctwocc"],
-                "scaling_factor_wcs_ctwcc": cncgsm[cg]["scaling_factor_wcs_ctwcc"],
-                "scaling_factor_wcs_csc": cncgsm[cg]["scaling_factor_wcs_csc"],
-                "translation_vector_wocs_ctwocc": cncgsm[cg]["translation_vector_wocs_ctwocc"],
-                "translation_vector_wocs_ctwcc": cncgsm[cg]["translation_vector_wocs_ctwcc"],
-                "translation_vector_wocs_csc": cncgsm[cg]["translation_vector_wocs_csc"],
-                "translation_vector_wcs_ctwocc": cncgsm[cg]["translation_vector_wcs_ctwocc"],
-                "translation_vector_wcs_ctwcc": cncgsm[cg]["translation_vector_wcs_ctwcc"],
-                "translation_vector_wcs_csc": cncgsm[cg]["translation_vector_wcs_csc"],
+                "csm_wocs_ctwocc": d["csm_wocs_ctwocc"],
+                "csm_wocs_ctwcc": d["csm_wocs_ctwcc"],
+                "csm_wocs_csc": d["csm_wocs_csc"],
+                "csm_wcs_ctwocc": d["csm_wcs_ctwocc"],
+                "csm_wcs_ctwcc": d["csm_wcs_ctwcc"],
+                "csm_wcs_csc": d["csm_wcs_csc"],
+                "rotation_matrix_wocs_ctwocc": d["rotation_matrix_wocs_ctwocc"],
+                "rotation_matrix_wocs_ctwcc": d["rotation_matrix_wocs_ctwcc"],
+                "rotation_matrix_wocs_csc": d["rotation_matrix_wocs_csc"],
+                "rotation_matrix_wcs_ctwocc": d["rotation_matrix_wcs_ctwocc"],
+                "rotation_matrix_wcs_ctwcc": d["rotation_matrix_wcs_ctwcc"],
+                "rotation_matrix_wcs_csc": d["rotation_matrix_wcs_csc"],
+                "scaling_factor_wocs_ctwocc": d["scaling_factor_wocs_ctwocc"],
+                "scaling_factor_wocs_ctwcc": d["scaling_factor_wocs_ctwcc"],
+                "scaling_factor_wocs_csc": d["scaling_factor_wocs_csc"],
+                "scaling_factor_wcs_ctwocc": d["scaling_factor_wcs_ctwocc"],
+                "scaling_factor_wcs_ctwcc": d["scaling_factor_wcs_ctwcc"],
+                "scaling_factor_wcs_csc": d["scaling_factor_wcs_csc"],
+                "translation_vector_wocs_ctwocc": d["translation_vector_wocs_ctwocc"],
+                "translation_vector_wocs_ctwcc": d["translation_vector_wocs_ctwcc"],
+                "translation_vector_wocs_csc": d["translation_vector_wocs_csc"],
+                "translation_vector_wcs_ctwocc": d["translation_vector_wcs_ctwocc"],
+                "translation_vector_wcs_ctwcc": d["translation_vector_wcs_ctwcc"],
+                "translation_vector_wcs_csc": d["translation_vector_wcs_csc"],
             }
             ce.add_coord_geom(
                 cg,
-                cncgsm[cg]["csm"],
-                algo=cncgsm[cg]["algo"],
-                permutation=cncgsm[cg]["indices"],
-                local2perfect_map=cncgsm[cg]["local2perfect_map"],
-                perfect2local_map=cncgsm[cg]["perfect2local_map"],
+                d["csm"],
+                algo=d["algo"],
+                permutation=d["indices"],
+                local2perfect_map=d["local2perfect_map"],
+                perfect2local_map=d["perfect2local_map"],
                 detailed_voronoi_index={"cn": cn, "index": inb_set},
                 other_symmetry_measures=other_csms,
-                rotation_matrix=cncgsm[cg]["rotation_matrix"],
-                scaling_factor=cncgsm[cg]["scaling_factor"],
+                rotation_matrix=d["rotation_matrix"],
+                scaling_factor=d["scaling_factor"],
             )
         se.update_coordination_environments(isite=isite, cn=cn, nb_set=nb_set, ce=ce)
         return ce
@@ -1097,7 +1100,7 @@ class LocalGeometryFinder:
         """
         aa = 0.4
         bb = -0.2
-        coords = list()
+        coords = []
         for ii in range(coordination + 1):
             coords.append(
                 aa
@@ -1170,10 +1173,10 @@ class LocalGeometryFinder:
                     "wcs_ctwcc",
                     "wcs_csc",
                 ]:
-                    result_dict["S:1"]["csm_{}".format(csmtype)] = 0.0
-                    result_dict["S:1"]["scaling_factor_{}".format(csmtype)] = None
-                    result_dict["S:1"]["rotation_matrix_{}".format(csmtype)] = None
-                    result_dict["S:1"]["translation_vector_{}".format(csmtype)] = None
+                    result_dict["S:1"][f"csm_{csmtype}"] = 0.0
+                    result_dict["S:1"][f"scaling_factor_{csmtype}"] = None
+                    result_dict["S:1"][f"rotation_matrix_{csmtype}"] = None
+                    result_dict["S:1"][f"translation_vector_{csmtype}"] = None
             return result_dict
         result_dict = {}
         for geometry in test_geometries:
@@ -1422,10 +1425,10 @@ class LocalGeometryFinder:
         #                                           np.float_)
         if optimization == 2:
             permutations_symmetry_measures = [None] * len(algo.permutations)
-            permutations = list()
-            algos = list()
-            local2perfect_maps = list()
-            perfect2local_maps = list()
+            permutations = []
+            algos = []
+            local2perfect_maps = []
+            perfect2local_maps = []
             for iperm, perm in enumerate(algo.permutations):
 
                 local2perfect_map = {}
@@ -1453,10 +1456,10 @@ class LocalGeometryFinder:
             )
 
         permutations_symmetry_measures = [None] * len(algo.permutations)
-        permutations = list()
-        algos = list()
-        local2perfect_maps = list()
-        perfect2local_maps = list()
+        permutations = []
+        algos = []
+        local2perfect_maps = []
+        perfect2local_maps = []
         for iperm, perm in enumerate(algo.permutations):
             local2perfect_map = {}
             perfect2local_map = {}
@@ -1496,14 +1499,14 @@ class LocalGeometryFinder:
         :param coordination_geometry: The coordination geometry to be investigated
         :return: The symmetry measures for the given coordination geometry for each plane and permutation investigated
         """
-        permutations = list()
-        permutations_symmetry_measures = list()
-        plane_separations = list()
-        algos = list()
-        perfect2local_maps = list()
-        local2perfect_maps = list()
+        permutations = []
+        permutations_symmetry_measures = []
+        plane_separations = []
+        algos = []
+        perfect2local_maps = []
+        local2perfect_maps = []
         if testing:
-            separation_permutations = list()
+            separation_permutations = []
         nplanes = 0
         for npoints in range(
             separation_plane_algo.minimum_number_of_points,
@@ -1616,11 +1619,11 @@ class LocalGeometryFinder:
             raise ValueError("Optimization should be 1 or 2")
         cn = len(self.local_geometry.coords)
 
-        permutations = list()
-        permutations_symmetry_measures = list()
-        algos = list()
-        perfect2local_maps = list()
-        local2perfect_maps = list()
+        permutations = []
+        permutations_symmetry_measures = []
+        algos = []
+        perfect2local_maps = []
+        local2perfect_maps = []
 
         if separation_plane_algo.separation in nb_set.separations:
             for sep_indices, (local_plane, npsep) in nb_set.separations[separation_plane_algo.separation].items():
@@ -1706,7 +1709,7 @@ class LocalGeometryFinder:
                         continue
                     if sep not in nb_set.separations:
                         nb_set.separations[sep] = {}
-                    mysep = [np.array(ss, dtype=np.int8) for ss in separation]
+                    mysep = [np.array(ss, dtype=int) for ss in separation]
                     nb_set.separations[sep][separation] = (plane, mysep)
                     if sep == separation_plane_algo.separation:
                         new_seps.append(mysep)
@@ -2019,10 +2022,10 @@ class LocalGeometryFinder:
         :return: The symmetry measures for the given coordination geometry for each permutation investigated
         """
         permutations_symmetry_measures = [None] * NRANDOM
-        permutations = list()
-        algos = list()
-        perfect2local_maps = list()
-        local2perfect_maps = list()
+        permutations = []
+        algos = []
+        perfect2local_maps = []
+        local2perfect_maps = []
         for iperm in range(NRANDOM):
             perm = np.random.permutation(coordination_geometry.coordination_number)
             permutations.append(perm)
