@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
@@ -54,13 +53,9 @@ class Defect(MSONable, metaclass=ABCMeta):
         self._structure = structure
         self._charge = int(charge)
         self._defect_site = defect_site
-        lattice_match = np.allclose(
-            structure.lattice.matrix, defect_site.lattice.matrix, atol=1e-5
-        )
+        lattice_match = np.allclose(structure.lattice.matrix, defect_site.lattice.matrix, atol=1e-5)
         if not lattice_match:
-            raise ValueError(
-                "defect_site lattice must be same as structure " "lattice."
-            )
+            raise ValueError("defect_site lattice must be same as structure lattice.")
         self._multiplicity = multiplicity if multiplicity else self.get_multiplicity()
 
     @property
@@ -176,9 +171,7 @@ class Vacancy(Defect):
         defect_site = struct_for_defect_site[0]
 
         poss_deflist = sorted(
-            defect_structure.get_sites_in_sphere(
-                defect_site.coords, 0.1, include_index=True
-            ),
+            defect_structure.get_sites_in_sphere(defect_site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         defindex = poss_deflist[0][2]
@@ -194,17 +187,11 @@ class Vacancy(Defect):
         sga = SpacegroupAnalyzer(self.bulk_structure)
         periodic_struc = sga.get_symmetrized_structure()
         poss_deflist = sorted(
-            periodic_struc.get_sites_in_sphere(
-                self.site.coords, 0.1, include_index=True
-            ),
+            periodic_struc.get_sites_in_sphere(self.site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         if not len(poss_deflist):
-            raise ValueError(
-                "Site {} is not in bulk structure! Cannot create Vacancy object.".format(
-                    self.site
-                )
-            )
+            raise ValueError(f"Site {self.site} is not in bulk structure! Cannot create Vacancy object.")
         defindex = poss_deflist[0][2]
         defect_site = self.bulk_structure[defindex]
         equivalent_sites = periodic_struc.find_equivalent_sites(defect_site)
@@ -215,7 +202,7 @@ class Vacancy(Defect):
         """
         Returns a name for this defect
         """
-        return "Vac_{}_mult{}".format(self.site.specie, self.multiplicity)
+        return f"Vac_{self.site.specie}_mult{self.multiplicity}"
 
 
 class Substitution(Defect):
@@ -230,9 +217,7 @@ class Substitution(Defect):
         Returns: Composition of defect.
         """
         poss_deflist = sorted(
-            self.bulk_structure.get_sites_in_sphere(
-                self.site.coords, 0.1, include_index=True
-            ),
+            self.bulk_structure.get_sites_in_sphere(self.site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         defindex = poss_deflist[0][2]
@@ -273,9 +258,7 @@ class Substitution(Defect):
         defect_site = struct_for_defect_site[0]
 
         poss_deflist = sorted(
-            defect_structure.get_sites_in_sphere(
-                defect_site.coords, 0.1, include_index=True
-            ),
+            defect_structure.get_sites_in_sphere(defect_site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         defindex = poss_deflist[0][2]
@@ -298,17 +281,11 @@ class Substitution(Defect):
         sga = SpacegroupAnalyzer(self.bulk_structure)
         periodic_struc = sga.get_symmetrized_structure()
         poss_deflist = sorted(
-            periodic_struc.get_sites_in_sphere(
-                self.site.coords, 0.1, include_index=True
-            ),
+            periodic_struc.get_sites_in_sphere(self.site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         if not len(poss_deflist):
-            raise ValueError(
-                "Site {} is not in bulk structure! Cannot create Substitution object.".format(
-                    self.site
-                )
-            )
+            raise ValueError(f"Site {self.site} is not in bulk structure! Cannot create Substitution object.")
         defindex = poss_deflist[0][2]
         defect_site = self.bulk_structure[defindex]
         equivalent_sites = periodic_struc.find_equivalent_sites(defect_site)
@@ -321,15 +298,11 @@ class Substitution(Defect):
         Returns a name for this defect
         """
         poss_deflist = sorted(
-            self.bulk_structure.get_sites_in_sphere(
-                self.site.coords, 0.1, include_index=True
-            ),
+            self.bulk_structure.get_sites_in_sphere(self.site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         defindex = poss_deflist[0][2]
-        return "Sub_{}_on_{}_mult{}".format(
-            self.site.specie, self.bulk_structure[defindex].specie, self.multiplicity
-        )
+        return f"Sub_{self.site.specie}_on_{self.bulk_structure[defindex].specie}_mult{self.multiplicity}"
 
 
 class Interstitial(Defect):
@@ -337,9 +310,7 @@ class Interstitial(Defect):
     Subclass of Defect to capture essential information for a single Interstitial defect structure.
     """
 
-    def __init__(
-        self, structure, defect_site, charge=0.0, site_name="", multiplicity=None
-    ):
+    def __init__(self, structure, defect_site, charge=0.0, site_name="", multiplicity=None):
         """
         Initializes an interstial defect.
         Args:
@@ -433,16 +404,12 @@ class Interstitial(Defect):
         sga = SpacegroupAnalyzer(d_structure)
         periodic_struc = sga.get_symmetrized_structure()
         poss_deflist = sorted(
-            periodic_struc.get_sites_in_sphere(
-                self.site.coords, 0.1, include_index=True
-            ),
+            periodic_struc.get_sites_in_sphere(self.site.coords, 0.1, include_index=True),
             key=lambda x: x[1],
         )
         defindex = poss_deflist[0][2]
 
-        equivalent_sites = periodic_struc.find_equivalent_sites(
-            periodic_struc[defindex]
-        )
+        equivalent_sites = periodic_struc.find_equivalent_sites(periodic_struc[defindex])
         return len(equivalent_sites)
 
     @property
@@ -451,10 +418,8 @@ class Interstitial(Defect):
         Returns a name for this defect
         """
         if self.site_name:
-            return "Int_{}_{}_mult{}".format(
-                self.site.specie, self.site_name, self.multiplicity
-            )
-        return "Int_{}_mult{}".format(self.site.specie, self.multiplicity)
+            return f"Int_{self.site.specie}_{self.site_name}_mult{self.multiplicity}"
+        return f"Int_{self.site.specie}_mult{self.multiplicity}"
 
 
 def create_saturated_interstitial_structure(interstitial_def, dist_tol=0.1):
@@ -483,7 +448,7 @@ def create_saturated_interstitial_structure(interstitial_def, dist_tol=0.1):
     # copy bulk structure to make saturated interstitial structure out of
     # artificially lower distance_tolerance to allow for distinct interstitials
     # with lower symmetry to be replicated - This is OK because one would never
-    # actually use this structure for a practical calcualtion...
+    # actually use this structure for a practical calculation...
     saturated_defect_struct = interstitial_def.bulk_structure.copy()
     saturated_defect_struct.DISTANCE_TOLERANCE = dist_tol
 
@@ -666,14 +631,8 @@ class DefectEntry(MSONable):
         chemical_potentials = chemical_potentials if chemical_potentials else {}
 
         chempot_correction = sum(
-            [
-                chem_pot
-                * (
-                    self.bulk_structure.composition[el]
-                    - self.defect.defect_composition[el]
-                )
-                for el, chem_pot in chemical_potentials.items()
-            ]
+            chem_pot * (self.bulk_structure.composition[el] - self.defect.defect_composition[el])
+            for el, chem_pot in chemical_potentials.items()
         )
 
         formation_energy = self.energy + chempot_correction
@@ -685,9 +644,7 @@ class DefectEntry(MSONable):
 
         return formation_energy
 
-    def defect_concentration(
-        self, chemical_potentials, temperature=300, fermi_level=0.0
-    ):
+    def defect_concentration(self, chemical_potentials, temperature=300, fermi_level=0.0):
         """
         Compute the defect concentration for a temperature and Fermi level.
         Args:
@@ -700,9 +657,7 @@ class DefectEntry(MSONable):
         """
         n = self.multiplicity * 1e24 / self.defect.bulk_structure.volume
         conc = n * np.exp(
-            -1.0
-            * self.formation_energy(chemical_potentials, fermi_level=fermi_level)
-            / (kb * temperature)
+            -1.0 * self.formation_energy(chemical_potentials, fermi_level=fermi_level) / (kb * temperature)
         )
 
         return conc
@@ -712,15 +667,13 @@ class DefectEntry(MSONable):
         Human readable string representation of this entry
         """
         output = [
-            "DefectEntry {} - {} - charge {}".format(
-                self.entry_id, self.name, self.charge
-            ),
-            "Energy = {:.4f}".format(self.energy),
-            "Correction = {:.4f}".format(np.sum(list(self.corrections.values()))),
+            f"DefectEntry {self.entry_id} - {self.name} - charge {self.charge}",
+            f"Energy = {self.energy:.4f}",
+            f"Correction = {np.sum(list(self.corrections.values())):.4f}",
             "Parameters:",
         ]
         for k, v in self.parameters.items():
-            output.append("\t{} = {}".format(k, v))
+            output.append(f"\t{k} = {v}")
         return "\n".join(output)
 
     def __str__(self):
