@@ -277,7 +277,7 @@ class DiffusionAnalyzer(MSONable):
                     dcomponents = dc[:, n:, :] - dc[:, :-n, :]
 
                 # Get msd
-                sq_disp = dx ** 2
+                sq_disp = dx**2
                 sq_disp_ions[:, i] = np.average(np.sum(sq_disp, axis=2), axis=1)
                 msd[i] = np.average(sq_disp_ions[:, i][indices])
 
@@ -343,7 +343,7 @@ class DiffusionAnalyzer(MSONable):
             # Drift and displacement information.
             self.drift = drift
             self.corrected_displacements = dc
-            self.max_ion_displacements = np.max(np.sum(dc ** 2, axis=-1) ** 0.5, axis=1)
+            self.max_ion_displacements = np.max(np.sum(dc**2, axis=-1) ** 0.5, axis=1)
             self.max_framework_displacement = np.max(self.max_ion_displacements[framework_indices])
             self.msd = msd
             self.mscd = mscd
@@ -565,7 +565,7 @@ class DiffusionAnalyzer(MSONable):
     def from_structures(
         cls, structures, specie, temperature, time_step, step_skip, initial_disp=None, initial_structure=None, **kwargs
     ):
-        r"""
+        """
         Convenient constructor that takes in a list of Structure objects to
         perform diffusion analysis.
 
@@ -590,7 +590,7 @@ class DiffusionAnalyzer(MSONable):
                 typically need to supply both variables. This stipulates the
                 initial structure from which the current set of displacements
                 are computed.
-            \\*\\*kwargs: kwargs supported by the :class:`DiffusionAnalyzer`_.
+            kwargs: kwargs supported by the :class:`DiffusionAnalyzer`_.
                 Examples include smoothed, min_obs, avg_nsteps.
         """
         p, l = [], []
@@ -627,7 +627,7 @@ class DiffusionAnalyzer(MSONable):
 
     @classmethod
     def from_vaspruns(cls, vaspruns, specie, initial_disp=None, initial_structure=None, **kwargs):
-        r"""
+        """
         Convenient constructor that takes in a list of Vasprun objects to
         perform diffusion analysis.
 
@@ -647,7 +647,7 @@ class DiffusionAnalyzer(MSONable):
                 typically need to supply both variables. This stipulates the
                 initial stricture from which the current set of displacements
                 are computed.
-            \\*\\*kwargs: kwargs supported by the :class:`DiffusionAnalyzer`_.
+            kwargs: kwargs supported by the :class:`DiffusionAnalyzer`_.
                 Examples include smoothed, min_obs, avg_nsteps.
         """
 
@@ -687,7 +687,7 @@ class DiffusionAnalyzer(MSONable):
     def from_files(
         cls, filepaths, specie, step_skip=10, ncores=None, initial_disp=None, initial_structure=None, **kwargs
     ):
-        r"""
+        """
         Convenient constructor that takes in a list of vasprun.xml paths to
         perform diffusion analysis.
 
@@ -719,7 +719,7 @@ class DiffusionAnalyzer(MSONable):
                 typically need to supply both variables. This stipulates the
                 initial structure from which the current set of displacements
                 are computed.
-            \\*\\*kwargs: kwargs supported by the :class:`DiffusionAnalyzer`_.
+            kwargs: kwargs supported by the :class:`DiffusionAnalyzer`_.
                 Examples include smoothed, min_obs, avg_nsteps.
         """
         if ncores is not None and len(filepaths) > 1:
@@ -812,7 +812,7 @@ def get_conversion_factor(structure, species, temperature):
     n = structure.composition[species]
 
     vol = structure.volume * 1e-24  # units cm^3
-    return 1000 * n / (vol * const.N_A) * z ** 2 * (const.N_A * const.e) ** 2 / (const.R * temperature)
+    return 1000 * n / (vol * const.N_A) * z**2 * (const.N_A * const.e) ** 2 / (const.R * temperature)
 
 
 def _get_vasprun(args):
@@ -884,7 +884,7 @@ def get_extrapolated_conductivity(temps, diffusivities, new_temp, structure, spe
 
 
 def get_arrhenius_plot(temps, diffusivities, diffusivity_errors=None, **kwargs):
-    r"""
+    """
     Returns an Arrhenius plot.
 
     Args:
@@ -893,7 +893,7 @@ def get_arrhenius_plot(temps, diffusivities, diffusivity_errors=None, **kwargs):
             from DiffusionAnalyzer.diffusivity).
         diffusivity_errors ([float]): A sequence of errors for the
             diffusivities. If None, no error bar is plotted.
-        \\*\\*kwargs:
+        kwargs:
             Any keyword args supported by matplotlib.pyplot.plot.
 
     Returns:
