@@ -1,15 +1,12 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module provides the Stress class used to create, manipulate, and
 calculate relevant properties of the stress tensor.
 """
 
 import math
-import warnings
 
 import numpy as np
 
@@ -63,7 +60,7 @@ class Stress(SquareTensor):
         """
         if not self.is_symmetric():
             raise ValueError(
-                "The stress tensor is not symmetric, Von Mises " "stress is based on a symmetric stress tensor."
+                "The stress tensor is not symmetric, Von Mises stress is based on a symmetric stress tensor."
             )
         return math.sqrt(3 * self.dev_principal_invariants[1])
 
@@ -80,7 +77,7 @@ class Stress(SquareTensor):
         returns the deviatoric component of the stress
         """
         if not self.is_symmetric:
-            raise warnings.warn("The stress tensor is not symmetric, " "so deviator stress will not be either")
+            raise ValueError("The stress tensor is not symmetric, so deviator stress will not be either")
         return self - self.mean_stress * np.eye(3)
 
     def piola_kirchoff_1(self, def_grad):
