@@ -1,7 +1,6 @@
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
-
 """
 This module implements various equation of states.
 
@@ -59,7 +58,7 @@ class EOSBase(metaclass=ABCMeta):
         self.eos_params = [a, b, c]
 
         v0 = -b / (2 * a)
-        e0 = a * (v0 ** 2) + b * v0 + c
+        e0 = a * (v0**2) + b * v0 + c
         b0 = 2 * a * v0
         b1 = 4  # b1 is usually a small number like 4
 
@@ -324,7 +323,7 @@ class BirchMurnaghan(EOSBase):
         """
         e0, b0, b1, v0 = tuple(params)
         eta = (v0 / volume) ** (1.0 / 3.0)
-        return e0 + 9.0 * b0 * v0 / 16.0 * (eta ** 2 - 1) ** 2 * (6 + b1 * (eta ** 2 - 1.0) - 4.0 * eta ** 2)
+        return e0 + 9.0 * b0 * v0 / 16.0 * (eta**2 - 1) ** 2 * (6 + b1 * (eta**2 - 1.0) - 4.0 * eta**2)
 
 
 class PourierTarantola(EOSBase):
@@ -339,7 +338,7 @@ class PourierTarantola(EOSBase):
         e0, b0, b1, v0 = tuple(params)
         eta = (volume / v0) ** (1.0 / 3.0)
         squiggle = -3.0 * np.log(eta)
-        return e0 + b0 * v0 * squiggle ** 2 / 6.0 * (3.0 + squiggle * (b1 - 2))
+        return e0 + b0 * v0 * squiggle**2 / 6.0 * (3.0 + squiggle * (b1 - 2))
 
 
 class Vinet(EOSBase):
@@ -383,7 +382,7 @@ class PolynomialEOS(EOSBase):
         and set to the _params attribute.
         """
         fit_poly = np.poly1d(self.eos_params)
-        # the volume at min energy, used as the intial guess for the
+        # the volume at min energy, used as the initial guess for the
         # optimization wrt volume.
         v_e_min = self.volumes[np.argmin(self.energies)]
         # evaluate e0, v0, b0 and b1
@@ -409,7 +408,7 @@ class DeltaFactor(PolynomialEOS):
 
     def fit(self, order=3):
         """
-        Overriden since this eos works with volume**(2/3) instead of volume.
+        Overridden since this eos works with volume**(2/3) instead of volume.
         """
         x = self.volumes ** (-2.0 / 3.0)
         self.eos_params = np.polyfit(x, self.energies, order)
@@ -417,7 +416,7 @@ class DeltaFactor(PolynomialEOS):
 
     def _set_params(self):
         """
-        Overriden to account for the fact the fit with volume**(2/3) instead
+        Overridden to account for the fact the fit with volume**(2/3) instead
         of volume.
         """
         deriv0 = np.poly1d(self.eos_params)
@@ -432,7 +431,7 @@ class DeltaFactor(PolynomialEOS):
         else:
             raise EOSError("No minimum could be found")
 
-        derivV2 = 4.0 / 9.0 * x ** 5.0 * deriv2(x)
+        derivV2 = 4.0 / 9.0 * x**5.0 * deriv2(x)
         derivV3 = -20.0 / 9.0 * x ** (13.0 / 2.0) * deriv2(x) - 8.0 / 27.0 * x ** (15.0 / 2.0) * deriv3(x)
         b0 = derivV2 / x ** (3.0 / 2.0)
         b1 = -1 - x ** (-3.0 / 2.0) * derivV3 / derivV2
@@ -532,7 +531,7 @@ class NumericalEOS(PolynomialEOS):
         for k, v in all_coeffs.items():
             # weighted rms = rms * polynomial order / rms_min / ndata_fit
             weighted_rms = v[1] * k[0] / rms_min / k[1]
-            weight = np.exp(-(weighted_rms ** 2))
+            weight = np.exp(-(weighted_rms**2))
             norm += weight
             coeffs = np.array(v[0])
             # pad the coefficient array with zeros
