@@ -23,9 +23,9 @@ __author__ = "Pymatgen Development Team"
 __email__ = "pymatgen@googlegroups.com"
 __maintainer__ = "Shyue Ping Ong"
 __maintainer_email__ = "shyuep@gmail.com"
-__version__ = "2022.2.7"
+__version__ = "2022.2.10"
+
 
-yaml = YAML()
 SETTINGS_FILE = os.path.join(os.path.expanduser("~"), ".pmgrc.yaml")
 
 
@@ -39,15 +39,16 @@ def _load_pmg_settings():
             d["PMG_" + k] = v
 
     # Override anything in env vars with that in yml file
-    try:
-        with open(SETTINGS_FILE) as f:
-            d_yml = yaml.load(f)
-        d.update(d_yml)
-    except Exception as ex:
-        # If there are any errors, default to using environment variables
-        # if present.
-        warnings.warn(f"Error loading .pmgrc.yaml: {ex}. You may need to reconfigure your yaml file.")
-        pass
+    if os.path.exists(SETTINGS_FILE):
+        try:
+            yaml = YAML()
+            with open(SETTINGS_FILE) as f:
+                d_yml = yaml.load(f)
+            d.update(d_yml)
+        except Exception as ex:
+            # If there are any errors, default to using environment variables
+            # if present.
+            warnings.warn(f"Error loading .pmgrc.yaml: {ex}. You may need to reconfigure your yaml file.")
 
     return d
 
