@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
@@ -39,9 +38,9 @@ class Trajectory(MSONable):
 
     def __init__(
         self,
-        lattice: Union[List, np.ndarray, Lattice],
+        lattice: Union[Sequence[float], Sequence[Sequence[float]], np.ndarray, Lattice],
         species: List[Union[str, Element, Species, DummySpecies, Composition]],
-        frac_coords: List[Sequence[Sequence[float]]],
+        frac_coords: Union[List[Sequence[Sequence[float]]], np.ndarray],
         time_step: float = 2,
         site_properties: dict = None,
         frame_properties: dict = None,
@@ -105,7 +104,7 @@ class Trajectory(MSONable):
         if not constant_lattice and np.shape(lattice) == (3, 3):
             self.lattice = [lattice for i in range(np.shape(self.frac_coords)[0])]
         else:
-            self.lattice = lattice
+            self.lattice = lattice  # type: ignore
         self.constant_lattice = constant_lattice
         self.species = species
         self.site_properties = site_properties
@@ -137,14 +136,10 @@ class Trajectory(MSONable):
         Converts position coordinates of trajectory into displacements between consecutive frames
         """
         if not self.coords_are_displacement:
-            displacements = np.subtract(
-                self.frac_coords, np.roll(self.frac_coords, 1, axis=0)
-            )
+            displacements = np.subtract(self.frac_coords, np.roll(self.frac_coords, 1, axis=0))
             displacements[0] = np.zeros(np.shape(self.frac_coords[0]))
             # Deal with PBC
-            displacements = [
-                np.subtract(item, np.round(item)) for item in displacements
-            ]
+            displacements = [np.subtract(item, np.round(item)) for item in displacements]
 
             self.frac_coords = displacements
             self.coords_are_displacement = True
@@ -156,17 +151,10 @@ class Trajectory(MSONable):
             trajectory (Trajectory): Trajectory to add
         """
         if self.time_step != trajectory.time_step:
-            raise ValueError(
-                "Trajectory not extended: Time steps of trajectories is incompatible"
-            )
+            raise ValueError("Trajectory not extended: Time steps of trajectories is incompatible")
 
-        if (
-            len(self.species) != len(trajectory.species)
-            and self.species != trajectory.species
-        ):
-            raise ValueError(
-                "Trajectory not extended: species in trajectory do not match"
-            )
+        if len(self.species) != len(trajectory.species) and self.species != trajectory.species:
+            raise ValueError("Trajectory not extended: species in trajectory do not match")
 
         # Ensure both trajectories are in positions before combining
         self.to_positions()
@@ -185,9 +173,7 @@ class Trajectory(MSONable):
             np.shape(trajectory.frac_coords)[0],
         )
 
-        self.frac_coords = np.concatenate(
-            (self.frac_coords, trajectory.frac_coords), axis=0
-        )
+        self.frac_coords = np.concatenate((self.frac_coords, trajectory.frac_coords), axis=0)
         self.lattice, self.constant_lattice = self._combine_lattice(
             self.lattice,
             trajectory.lattice,
@@ -223,13 +209,9 @@ class Trajectory(MSONable):
                 return [self.frac_coords[i] for i in range(start, stop, step)]
             if isinstance(frames, (list, np.ndarray)):
                 # For list input, return a list of the displacements
-                pruned_frames = [
-                    i for i in frames if i < len(self)
-                ]  # Get rid of frames that exceed trajectory length
+                pruned_frames = [i for i in frames if i < len(self)]  # Get rid of frames that exceed trajectory length
                 if len(pruned_frames) < len(frames):
-                    warnings.warn(
-                        "Some or all selected frames exceed trajectory length"
-                    )
+                    warnings.warn("Some or all selected frames exceed trajectory length")
                 return [self.frac_coords[i] for i in pruned_frames]
             raise Exception("Given accessor is not of type int, slice, list, or array")
 
@@ -239,12 +221,8 @@ class Trajectory(MSONable):
                 raise ValueError("Selected frame exceeds trajectory length")
             # For integer input, return the structure at that timestep
             lattice = self.lattice if self.constant_lattice else self.lattice[frames]
-            site_properties = (
-                self.site_properties[frames] if self.site_properties else None
-            )
-            site_properties = (
-                self.site_properties[frames] if self.site_properties else None
-            )
+            site_properties = self.site_properties[frames] if self.site_properties else None
+            site_properties = self.site_properties[frames] if self.site_properties else None
             return Structure(
                 Lattice(lattice),
                 self.species,
@@ -256,11 +234,7 @@ class Trajectory(MSONable):
             # For slice input, return a trajectory of the sliced time
             start, stop, step = frames.indices(len(self))
             pruned_frames = range(start, stop, step)
-            lattice = (
-                self.lattice
-                if self.constant_lattice
-                else [self.lattice[i] for i in pruned_frames]
-            )
+            lattice = self.lattice if self.constant_lattice else [self.lattice[i] for i in pruned_frames]
             frac_coords = [self.frac_coords[i] for i in pruned_frames]
             if self.site_properties is not None:
                 site_properties = [self.site_properties[i] for i in pruned_frames]
@@ -285,16 +259,10 @@ class Trajectory(MSONable):
             )
         if isinstance(frames, (list, np.ndarray)):
             # For list input, return a trajectory of the specified times
-            pruned_frames = [
-                i for i in frames if i < len(self)
-            ]  # Get rid of frames that exceed trajectory length
+            pruned_frames = [i for i in frames if i < len(self)]  # Get rid of frames that exceed trajectory length
             if len(pruned_frames) < len(frames):
                 warnings.warn("Some or all selected frames exceed trajectory length")
-            lattice = (
-                self.lattice
-                if self.constant_lattice
-                else [self.lattice[i] for i in pruned_frames]
-            )
+            lattice = self.lattice if self.constant_lattice else [self.lattice[i] for i in pruned_frames]
             frac_coords = [self.frac_coords[i] for i in pruned_frames]
             if self.site_properties is not None:
                 site_properties = [self.site_properties[i] for i in pruned_frames]
@@ -317,9 +285,7 @@ class Trajectory(MSONable):
                 coords_are_displacement=False,
                 base_positions=self.base_positions,
             )
-        raise Exception(
-            "Given accessor is not of type int, slice, tuple, list, or array"
-        )
+        raise Exception("Given accessor is not of type int, slice, tuple, list, or array")
 
     def copy(self):
         """
@@ -388,9 +354,7 @@ class Trajectory(MSONable):
         else:
             raise ValueError("Unsupported file")
 
-        return cls.from_structures(
-            structures, constant_lattice=constant_lattice, **kwargs
-        )
+        return cls.from_structures(structures, constant_lattice=constant_lattice, **kwargs)
 
     def as_dict(self):
         """
@@ -424,12 +388,8 @@ class Trajectory(MSONable):
             attribute = np.concatenate((attr_1, attr_2), axis=0)
             attribute_constant = False
         else:
-            attribute = (
-                [attr_1.copy()] * len_1 if isinstance(attr_1, list) else attr_1.copy()
-            )
-            attribute.extend(
-                [attr_2.copy()] * len_2 if isinstance(attr_2, list) else attr_2.copy()
-            )
+            attribute = [attr_1.copy()] * len_1 if isinstance(attr_1, list) else attr_1.copy()
+            attribute.extend([attr_2.copy()] * len_2 if isinstance(attr_2, list) else attr_2.copy())
             attribute_constant = False
         return attribute, attribute_constant
 
@@ -533,7 +493,7 @@ class Trajectory(MSONable):
             system = f"{self[0].composition.reduced_formula}"
 
         lines = []
-        format_str = "{{:.{0}f}}".format(significant_figures)
+        format_str = f"{{:.{significant_figures}f}}"
         syms = [site.specie.symbol for site in self[0]]
         site_symbols = [a[0] for a in itertools.groupby(syms)]
         syms = [site.specie.symbol for site in self[0]]
@@ -541,7 +501,7 @@ class Trajectory(MSONable):
 
         for si, frac_coords in enumerate(self.frac_coords):
             # Only print out the info block if
-            if self.constant_lattice and si == 0:
+            if si == 0 or not self.constant_lattice:
                 lines.extend([system, "1.0"])
 
                 if self.constant_lattice:
@@ -555,7 +515,7 @@ class Trajectory(MSONable):
                 lines.append(" ".join(site_symbols))
                 lines.append(" ".join([str(x) for x in natoms]))
 
-            lines.append(f"Direct configuration=     {str(si + 1)}")
+            lines.append(f"Direct configuration=     {si + 1}")
 
             for (frac_coord, specie) in zip(frac_coords, self.species):
                 coords = frac_coord
