@@ -1,11 +1,10 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 """
 This module provides
 """
 
-from collections import OrderedDict, namedtuple
+from collections import namedtuple
 
 from monty.functools import lazy_property
 from monty.json import MSONable  # , MontyEncoder
@@ -76,26 +75,25 @@ class XcFunc(MSONable):
     type_name = namedtuple("type_name", "type, name")
 
     xcf = LibxcFunc
-    defined_aliases = OrderedDict(
-        [  # (x, c) --> type_name
-            # LDAs
-            ((xcf.LDA_X, xcf.LDA_C_PW), type_name("LDA", "PW")),  # ixc 7
-            ((xcf.LDA_X, xcf.LDA_C_PW_MOD), type_name("LDA", "PW_MOD")),
-            ((xcf.LDA_X, xcf.LDA_C_PZ), type_name("LDA", "PZ")),  # ixc 2
-            ((xcf.LDA_X, xcf.LDA_C_WIGNER), type_name("LDA", "W")),  # ixc 4
-            ((xcf.LDA_X, xcf.LDA_C_HL), type_name("LDA", "HL")),  # ixc 5
-            ((xcf.LDA_X, xcf.LDA_C_GL), type_name("LDA", "GL")),
-            ((xcf.LDA_X, xcf.LDA_C_VWN), type_name("LDA", "VWN")),
-            # GGAs
-            ((xcf.GGA_X_PW91, xcf.GGA_C_PW91), type_name("GGA", "PW91")),
-            ((xcf.GGA_X_PBE, xcf.GGA_C_PBE), type_name("GGA", "PBE")),
-            ((xcf.GGA_X_RPBE, xcf.GGA_C_PBE), type_name("GGA", "RPBE")),  # ixc 15
-            ((xcf.GGA_X_PBE_R, xcf.GGA_C_PBE), type_name("GGA", "revPBE")),  # ixc 14
-            ((xcf.GGA_X_PBE_SOL, xcf.GGA_C_PBE_SOL), type_name("GGA", "PBEsol")),
-            ((xcf.GGA_X_AM05, xcf.GGA_C_AM05), type_name("GGA", "AM05")),
-            ((xcf.GGA_X_B88, xcf.GGA_C_LYP), type_name("GGA", "BLYP")),
-        ]
-    )
+    defined_aliases = {  # (x, c) --> type_name
+        # LDAs
+        (xcf.LDA_X, xcf.LDA_C_PW): type_name("LDA", "PW"),  # ixc 7
+        (xcf.LDA_X, xcf.LDA_C_PW_MOD): type_name("LDA", "PW_MOD"),
+        (xcf.LDA_X, xcf.LDA_C_PZ): type_name("LDA", "PZ"),  # ixc 2
+        (xcf.LDA_X, xcf.LDA_C_WIGNER): type_name("LDA", "W"),  # ixc 4
+        (xcf.LDA_X, xcf.LDA_C_HL): type_name("LDA", "HL"),  # ixc 5
+        (xcf.LDA_X, xcf.LDA_C_GL): type_name("LDA", "GL"),
+        (xcf.LDA_X, xcf.LDA_C_VWN): type_name("LDA", "VWN"),
+        # GGAs
+        (xcf.GGA_X_PW91, xcf.GGA_C_PW91): type_name("GGA", "PW91"),
+        (xcf.GGA_X_PBE, xcf.GGA_C_PBE): type_name("GGA", "PBE"),
+        (xcf.GGA_X_RPBE, xcf.GGA_C_PBE): type_name("GGA", "RPBE"),  # ixc 15
+        (xcf.GGA_X_PBE_R, xcf.GGA_C_PBE): type_name("GGA", "revPBE"),  # ixc 14
+        (xcf.GGA_X_PBE_SOL, xcf.GGA_C_PBE_SOL): type_name("GGA", "PBEsol"),
+        (xcf.GGA_X_AM05, xcf.GGA_C_AM05): type_name("GGA", "AM05"),
+        (xcf.GGA_X_B88, xcf.GGA_C_LYP): type_name("GGA", "BLYP"),
+    }
+
     del type_name
 
     # Correspondence between Abinit ixc notation and libxc notation.
@@ -126,7 +124,7 @@ class XcFunc(MSONable):
             return obj
         if is_string(obj):
             return cls.from_name(obj)
-        raise TypeError("Don't know how to convert <%s:%s> to Xcfunc" % (type(obj), str(obj)))
+        raise TypeError(f"Don't know how to convert <{type(obj)}:{obj}> to Xcfunc")
 
     @classmethod
     def from_abinit_ixc(cls, ixc):
@@ -168,7 +166,7 @@ class XcFunc(MSONable):
                     return cls(xc=k)
                 if len(k) == 2:
                     return cls(x=k[0], c=k[1])
-                raise ValueError("Wrong key: %s" % k)
+                raise ValueError(f"Wrong key: {k}")
 
         # At this point, we should have something in the form
         # name="GGA_X_PBE+GGA_C_PBE" or  name=""LDA_XC_TETER93"
@@ -239,7 +237,7 @@ class XcFunc(MSONable):
         return "+".join([self.x.family, self.c.family])
 
     @lazy_property
-    def name(self):
+    def name(self) -> str:
         """
         The name of the functional. If the functional is not found in the aliases,
         the string has the form X_NAME+C_NAME
@@ -253,8 +251,8 @@ class XcFunc(MSONable):
             return self.xc.name
         return "+".join([self.x.name, self.c.name])
 
-    def __repr__(self):
-        return "%s" % self.name
+    def __repr__(self) -> str:
+        return str(self.name)
 
     def __hash__(self):
         return hash(self.name)
