@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
@@ -15,6 +14,7 @@ import warnings
 import numpy as np
 from monty.json import MSONable
 from scipy.interpolate import InterpolatedUnivariateSpline
+
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
 from pymatgen.electronic_structure.core import Orbital, Spin
@@ -36,16 +36,18 @@ class Cohp(MSONable):
     Basic COHP object.
     """
 
-    def __init__(self, efermi, energies, cohp, are_coops=False, icohp=None):
+    def __init__(self, efermi, energies, cohp, are_coops=False, are_cobis=False, icohp=None):
         """
         Args:
-            are_coops: Indicates whether this object describes COHPs or COOPs.
+            are_coops: Indicates whether this object describes COOPs.
+            are_cobis: Indicates whether this object describes COBIs.
             efermi: Fermi energy.
             energies: A sequence of energies.
             cohp ({Spin: np.array}): representing the COHP for each spin.
             icohp ({Spin: np.array}): representing the ICOHP for each spin.
         """
         self.are_coops = are_coops
+        self.are_cobis = are_cobis
         self.efermi = efermi
         self.energies = np.array(energies)
         self.cohp = cohp
@@ -58,7 +60,12 @@ class Cohp(MSONable):
         """
         Returns a string that can be easily plotted (e.g. using gnuplot).
         """
-        cohpstring = "COOP" if self.are_coops else "COHP"
+        if self.are_coops:
+            cohpstring = "COOP"
+        elif self.are_cobis:
+            cohpstring = "COBI"
+        else:
+            cohpstring = "COHP"
         header = ["Energy", cohpstring + "Up"]
         data = [self.energies, self.cohp[Spin.up]]
         if Spin.down in self.cohp:
@@ -74,7 +81,7 @@ class Cohp(MSONable):
         formatdata = " ".join(["{:.5f}" for __ in header])
         stringarray = [formatheader.format(*header)]
         for i, __ in enumerate(self.energies):
-            stringarray.append(formatdata.format(*[d[i] for d in data]))
+            stringarray.append(formatdata.format(*(d[i] for d in data)))
         return "\n".join(stringarray)
 
     def as_dict(self):
@@ -85,6 +92,7 @@ class Cohp(MSONable):
             "@module": self.__class__.__module__,
             "@class": self.__class__.__name__,
             "are_coops": self.are_coops,
+            "are_cobis": self.are_cobis,
             "efermi": self.efermi,
             "energies": self.energies.tolist(),
             "COHP": {str(spin): pops.tolist() for spin, pops in self.cohp.items()},
@@ -191,12 +199,17 @@ class Cohp(MSONable):
             icohp = {Spin(int(key)): np.array(val) for key, val in d["ICOHP"].items()}
         else:
             icohp = None
+        if "are_cobis" not in d:
+            are_cobis = False
+        else:
+            are_cobis = d["are_cobis"]
         return Cohp(
             d["efermi"],
             d["energies"],
             {Spin(int(key)): np.array(val) for key, val in d["COHP"].items()},
             icohp=icohp,
             are_coops=d["are_coops"],
+            are_cobis=are_cobis,
         )
 
 
@@ -206,7 +219,13 @@ class CompleteCohp(Cohp):
 
     .. attribute: are_coops
 
-         Indicates whether the object is of COOPs or COHPs.
+         Indicates whether the object is consisting of COOPs.
+
+
+    .. attribute: are_cobis
+
+         Indicates whether the object is consisting of COBIs.
+
 
     .. attribute: efermi
 
@@ -240,11 +259,12 @@ class CompleteCohp(Cohp):
         cohp_dict,
         bonds=None,
         are_coops=False,
+        are_cobis=False,
         orb_res_cohp=None,
     ):
         """
         Args:
-            structure: Structure assosciated with this COHP.
+            structure: Structure associated with this COHP.
             avg_cohp: The average cohp as a COHP object.
             cohps: A dict of COHP objects for individual bonds of the form
                 {label: COHP}
@@ -253,19 +273,25 @@ class CompleteCohp(Cohp):
                 the user wants to put in, but typically contains the sites,
                 the bond length, and the number of bonds. If nothing is
                 supplied, it will default to an empty dict.
-            are_coops: indicates whether the Cohp objects are COHPs or COOPs.
-                Defauls to False for COHPs.
+            are_coops: indicates whether the Cohp objects are COOPs.
+                Defaults to False for COHPs.
+            are_cobis: indicates whether the Cohp objects are COBIs.
+                Defaults to False for COHPs.
             orb_res_cohp: Orbital-resolved COHPs.
         """
+        if are_coops and are_cobis:
+            raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
         super().__init__(
             avg_cohp.efermi,
             avg_cohp.energies,
             avg_cohp.cohp,
             are_coops=are_coops,
+            are_cobis=are_cobis,
             icohp=avg_cohp.icohp,
         )
         self.structure = structure
         self.are_coops = are_coops
+        self.are_cobis = are_cobis
         self.all_cohps = cohp_dict
         self.orb_res_cohp = orb_res_cohp
         if bonds is None:
@@ -276,6 +302,8 @@ class CompleteCohp(Cohp):
     def __str__(self):
         if self.are_coops:
             return "Complete COOPs for " + str(self.structure)
+        if self.are_cobis:
+            return "Complete COBIs for " + str(self.structure)
         return "Complete COHPs for " + str(self.structure)
 
     def as_dict(self):
@@ -286,6 +314,7 @@ class CompleteCohp(Cohp):
             "@module": self.__class__.__module__,
             "@class": self.__class__.__name__,
             "are_coops": self.are_coops,
+            "are_cobis": self.are_cobis,
             "efermi": self.efermi,
             "structure": self.structure.as_dict(),
             "energies": self.energies.tolist(),
@@ -363,6 +392,7 @@ class CompleteCohp(Cohp):
             energies=self.energies,
             cohp=final_cohp,
             are_coops=self.are_coops,
+            are_cobis=self.are_cobis,
             icohp=final_icohp,
         )
 
@@ -415,6 +445,7 @@ class CompleteCohp(Cohp):
             energies=first_cohpobject.energies,
             cohp=final_cohp,
             are_coops=first_cohpobject.are_coops,
+            are_cobis=first_cohpobject.are_coops,
             icohp=final_icohp,
         )
 
@@ -473,6 +504,7 @@ class CompleteCohp(Cohp):
             energies=first_cohpobject.energies,
             cohp=final_cohp,
             are_coops=first_cohpobject.are_coops,
+            are_cobis=first_cohpobject.are_cobis,
             icohp=final_icohp,
         )
 
@@ -541,6 +573,7 @@ class CompleteCohp(Cohp):
             final_cohp,
             icohp=final_icohp,
             are_coops=self.are_coops,
+            are_cobis=self.are_cobis,
         )
 
     @classmethod
@@ -641,17 +674,23 @@ class CompleteCohp(Cohp):
                 icohp = None
             avg_cohp = Cohp(efermi, energies, cohp, icohp=icohp)
 
+        if "are_cobis" not in d:
+            are_cobis = False
+        else:
+            are_cobis = d["are_cobis"]
+
         return CompleteCohp(
             structure,
             avg_cohp,
             cohp_dict,
             bonds=bonds,
             are_coops=d["are_coops"],
+            are_cobis=are_cobis,
             orb_res_cohp=orb_cohp,
         )
 
     @classmethod
-    def from_file(cls, fmt, filename=None, structure_file=None, are_coops=False):
+    def from_file(cls, fmt, filename=None, structure_file=None, are_coops=False, are_cobis=False):
         """
         Creates a CompleteCohp object from an output file of a COHP
         calculation. Valid formats are either LMTO (for the Stuttgart
@@ -664,6 +703,9 @@ class CompleteCohp(Cohp):
             are_coops: Indicates whether the populations are COOPs or
                 COHPs. Defaults to False for COHPs.
 
+            are_cobis: Indicates whether the populations are COBIs or
+                COHPs. Defaults to False for COHPs.
+
             fmt: A string for the code that was used to calculate
                 the COHPs so that the output file can be handled
                 correctly. Can take the values "LMTO" or "LOBSTER".
@@ -675,10 +717,13 @@ class CompleteCohp(Cohp):
         Returns:
             A CompleteCohp object.
         """
+        if are_coops and are_cobis:
+            raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
         fmt = fmt.upper()
         if fmt == "LMTO":
             # LMTO COOPs and orbital-resolved COHP cannot be handled yet.
             are_coops = False
+            are_cobis = False
             orb_res_cohp = None
             if structure_file is None:
                 structure_file = "CTRL"
@@ -686,18 +731,22 @@ class CompleteCohp(Cohp):
                 filename = "COPL"
             cohp_file = LMTOCopl(filename=filename, to_eV=True)
         elif fmt == "LOBSTER":
+            if are_coops and are_cobis:
+                raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
             if structure_file is None:
                 structure_file = "POSCAR"
             if filename is None:
-                filename = "COOPCAR.lobster" if are_coops else "COHPCAR.lobster"
-            warnings.warn(
-                "The bond labels are currently consistent with ICOHPLIST.lobster/ICOOPLIST.lobster, not with "
-                "COHPCAR.lobster/COOPCAR.lobster. Please be aware!"
-            )
-            cohp_file = Cohpcar(filename=filename, are_coops=are_coops)
+                if filename is None:
+                    if are_coops:
+                        filename = "COOPCAR.lobster"
+                    elif are_cobis:
+                        filename = "COBICAR.lobster"
+                    else:
+                        filename = "COHPCAR.lobster"
+            cohp_file = Cohpcar(filename=filename, are_coops=are_coops, are_cobis=are_cobis)
             orb_res_cohp = cohp_file.orb_res_cohp
         else:
-            raise ValueError("Unknown format %s. Valid formats are LMTO " "and LOBSTER." % fmt)
+            raise ValueError(f"Unknown format {fmt}. Valid formats are LMTO and LOBSTER.")
 
         structure = Structure.from_file(structure_file)
         efermi = cohp_file.efermi
@@ -741,9 +790,9 @@ class CompleteCohp(Cohp):
             # Calculate the average COHP for the LMTO file to be
             # consistent with LOBSTER output.
             avg_data = {"COHP": {}, "ICOHP": {}}
-            for i in avg_data:
+            for i in avg_data:  # pylint: disable=C0206
                 for spin in spins:
-                    rows = np.array([cohp_data[label][i][spin] for label in cohp_data])
+                    rows = np.array([v[i][spin] for v in cohp_data.values()])
                     avg = np.average(rows, axis=0)
                     # LMTO COHPs have 5 significant figures
                     avg_data[i].update({spin: np.array([round_to_sigfigs(a, 5) for a in avg], dtype=float)})
@@ -755,26 +804,21 @@ class CompleteCohp(Cohp):
                 cohp_data["average"]["COHP"],
                 icohp=cohp_data["average"]["COHP"],
                 are_coops=are_coops,
+                are_cobis=are_cobis,
             )
             del cohp_data["average"]
 
         cohp_dict = {
-            label: Cohp(
-                efermi,
-                energies,
-                cohp_data[label]["COHP"],
-                icohp=cohp_data[label]["ICOHP"],
-                are_coops=are_coops,
-            )
-            for label in cohp_data
+            label: Cohp(efermi, energies, v["COHP"], icohp=v["ICOHP"], are_coops=are_coops, are_cobis=are_cobis)
+            for label, v in cohp_data.items()
         }
 
         bond_dict = {
             label: {
-                "length": cohp_data[label]["length"],
-                "sites": [structure.sites[site] for site in cohp_data[label]["sites"]],
+                "length": v["length"],
+                "sites": [structure.sites[site] for site in v["sites"]],
             }
-            for label in cohp_data
+            for label, v in cohp_data.items()
         }
 
         return CompleteCohp(
@@ -783,6 +827,7 @@ class CompleteCohp(Cohp):
             cohp_dict,
             bonds=bond_dict,
             are_coops=are_coops,
+            are_cobis=are_cobis,
             orb_res_cohp=orb_res_cohp,
         )
 
@@ -795,7 +840,10 @@ class IcohpValue(MSONable):
             number of bonds used for the average cohp (relevant for Lobster versions <3.0) (int)
 
     .. attribute:: are_coops
-            Boolean to indicate whether ICOOP or not
+            Boolean to indicates ICOOPs
+
+    .. attribute:: are_cobis
+            Boolean to indicates ICOBIs
 
     .. attribute:: icohp
             dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
@@ -805,7 +853,7 @@ class IcohpValue(MSONable):
 
     """
 
-    def __init__(self, label, atom1, atom2, length, translation, num, icohp, are_coops=False):
+    def __init__(self, label, atom1, atom2, length, translation, num, icohp, are_coops=False, are_cobis=False):
         """
         Args:
             label: label for the icohp
@@ -815,8 +863,13 @@ class IcohpValue(MSONable):
             translation: translation list, e.g. [0,0,0]
             num: integer describing how often the bond exists
             icohp: dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
+            are_coops: if True, this are COOPs
+            are_cobis: if True, this are COBIs
         """
+        if are_coops and are_cobis:
+            raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
         self._are_coops = are_coops
+        self._are_cobis = are_cobis
         self._label = label
         self._atom1 = atom1
         self._atom2 = atom2
@@ -831,7 +884,7 @@ class IcohpValue(MSONable):
 
     def __str__(self):
 
-        if not self._are_coops:
+        if not self._are_coops and not self._are_cobis:
             if self._is_spin_polarized:
                 return (
                     "ICOHP "
@@ -861,7 +914,23 @@ class IcohpValue(MSONable):
                 + str(self._icohp[Spin.up])
                 + " eV (Spin up)"
             )
-        if self._is_spin_polarized:
+        if self._are_coops:
+            if self._is_spin_polarized:
+                return (
+                    "ICOOP "
+                    + str(self._label)
+                    + " between "
+                    + str(self._atom1)
+                    + " and "
+                    + str(self._atom2)
+                    + " ("
+                    + str(self._translation)
+                    + "): "
+                    + str(self._icohp[Spin.up])
+                    + " (Spin up) and "
+                    + str(self._icohp[Spin.down])
+                    + " (Spin down)"
+                )
             return (
                 "ICOOP "
                 + str(self._label)
@@ -873,12 +942,26 @@ class IcohpValue(MSONable):
                 + str(self._translation)
                 + "): "
                 + str(self._icohp[Spin.up])
+                + " (Spin up)"
+            )
+        if self._is_spin_polarized:
+            return (
+                "ICOBI "
+                + str(self._label)
+                + " between "
+                + str(self._atom1)
+                + " and "
+                + str(self._atom2)
+                + " ("
+                + str(self._translation)
+                + "): "
+                + str(self._icohp[Spin.up])
                 + " (Spin up) and "
                 + str(self._icohp[Spin.down])
                 + " (Spin down)"
             )
         return (
-            "ICOOP "
+            "ICOBI "
             + str(self._label)
             + " between "
             + str(self._atom1)
@@ -909,6 +992,15 @@ class IcohpValue(MSONable):
         """
         return self._are_coops
 
+    @property
+    def are_cobis(self):
+        """
+        tells if ICOBIs or not
+        Returns:
+            Boolean
+        """
+        return self._are_cobis
+
     @property
     def is_spin_polarized(self):
         """
@@ -959,7 +1051,10 @@ class IcohpCollection(MSONable):
     Class to store IcohpValues
 
     .. attribute:: are_coops
-        Boolean to indicate whether ICOHPs or ICOOPs are stored
+        Boolean to indicate if this are ICOOPs
+
+    .. attribute:: are_cobis
+        Boolean to indicate if this are ICOOPs
 
     .. attribute:: is_spin_polarized
         Boolean to indicate if the Lobster calculation was done spin polarized or not
@@ -977,12 +1072,14 @@ class IcohpCollection(MSONable):
         list_icohp,
         is_spin_polarized,
         are_coops=False,
+        are_cobis=False,
     ):
         """
         Args:
             is_spin_polarized: Boolean to indicate if the Lobster calculation was done spin polarized or not Boolean to
                 indicate if the Lobster calculation was done spin polarized or not
-            are_coops: Boolean to indicate whether ICOHPs or ICOOPs are stored
+            are_coops: Boolean to indicate whether ICOOPs are stored
+            are_cobis: Boolean to indicate whether ICOBIs are stored
             list_labels: list of labels for ICOHP/ICOOP values
             list_atom1: list of str of atomnames e.g. "O1"
             list_atom2: list of str of atomnames e.g. "O1"
@@ -991,7 +1088,10 @@ class IcohpCollection(MSONable):
             list_num: list of equivalent bonds, usually 1 starting from Lobster 3.0.0
             list_icohp: list of dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}
         """
+        if are_coops and are_cobis:
+            raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
         self._are_coops = are_coops
+        self._are_cobis = are_cobis
         self._icohplist = {}
         self._is_spin_polarized = is_spin_polarized
         self._list_labels = list_labels
@@ -1004,13 +1104,15 @@ class IcohpCollection(MSONable):
 
         for ilist, listel in enumerate(list_labels):
             self._icohplist[listel] = IcohpValue(
-                listel,
-                list_atom1[ilist],
-                list_atom2[ilist],
-                list_length[ilist],
-                list_translation[ilist],
-                list_num[ilist],
-                list_icohp[ilist],
+                label=listel,
+                atom1=list_atom1[ilist],
+                atom2=list_atom2[ilist],
+                length=list_length[ilist],
+                translation=list_translation[ilist],
+                num=list_num[ilist],
+                icohp=list_icohp[ilist],
+                are_coops=are_coops,
+                are_cobis=are_cobis,
             )
 
     def __str__(self):
@@ -1071,7 +1173,7 @@ class IcohpCollection(MSONable):
 
     def get_icohp_dict_by_bondlengths(self, minbondlength=0.0, maxbondlength=8.0):
         """
-        get a dict of IcohpValues corresponding to certaind bond lengths
+        get a dict of IcohpValues corresponding to certain bond lengths
         Args:
             minbondlength: defines the minimum of the bond lengths of the bonds
             maxbondlength: defines the maximum of the bond lengths of the bonds
@@ -1150,10 +1252,10 @@ class IcohpCollection(MSONable):
         Returns:
             lowest ICOHP/largest ICOOP value (i.e. ICOHP/ICOOP value of strongest bond)
         """
-        if not self._are_coops:
-            extremum = sys.float_info.max
-        else:
+        if self._are_coops or self._are_cobis:
             extremum = -sys.float_info.max
+        else:
+            extremum = sys.float_info.max
 
         if not self._is_spin_polarized:
             if spin == Spin.down:
@@ -1162,7 +1264,7 @@ class IcohpCollection(MSONable):
 
         for value in self._icohplist.values():
             if not value.is_spin_polarized or not summed_spin_channels:
-                if not self._are_coops:
+                if not self._are_coops and not self._are_cobis:
                     if value.icohpvalue(spin) < extremum:
                         extremum = value.icohpvalue(spin)
                         # print(extremum)
@@ -1171,7 +1273,7 @@ class IcohpCollection(MSONable):
                         extremum = value.icohpvalue(spin)
                         # print(extremum)
             else:
-                if not self._are_coops:
+                if not self._are_coops and not self._are_cobis:
                     if value.summed_icohp < extremum:
                         extremum = value.summed_icohp
                         # print(extremum)
@@ -1191,10 +1293,17 @@ class IcohpCollection(MSONable):
     @property
     def are_coops(self):
         """
-        :return: Whether this is coops.
+        :return: Whether this is a coop.
         """
         return self._are_coops
 
+    @property
+    def are_cobis(self):
+        """
+        :return: Whether this a cobi.
+        """
+        return self._are_cobis
+
 
 def get_integrated_cohp_in_energy_range(
     cohp, label, orbital=None, energy_range=None, relative_E_Fermi=True, summed_spin_channels=True
