@@ -3,26 +3,20 @@ This module calculates corrections for the species listed below, fitted to the e
 entries given to the CorrectionCalculator constructor.
 """
 
+import os
 import warnings
-from collections import OrderedDict
-from typing import Dict, List, Tuple, Union, Sequence
+from typing import Dict, List, Optional, Tuple, Union
 
-try:
-    import ruamel.yaml as yaml
-except ImportError:
-    try:
-        import ruamel_yaml as yaml  # type: ignore  # noqa
-    except ImportError:
-        import yaml  # type: ignore # noqa
 import numpy as np
 import plotly.graph_objects as go
 from monty.serialization import loadfn
+from ruamel import yaml
 from scipy.optimize import curve_fit
 
-from pymatgen.core.composition import Composition
-from pymatgen.core.periodic_table import Element
 from pymatgen.analysis.reaction_calculator import ComputedReaction
 from pymatgen.analysis.structure_analyzer import sulfide_type
+from pymatgen.core.composition import Composition
+from pymatgen.core.periodic_table import Element
 
 
 def _func(x, *m):
@@ -51,7 +45,7 @@ class CorrectionCalculator:
 
     def __init__(
         self,
-        species: Sequence[str] = (
+        species: List[str] = [
             "oxide",
             "peroxide",
             "superoxide",
@@ -74,19 +68,31 @@ class CorrectionCalculator:
             "W",
             "Mo",
             "H",
-        ),
+        ],
         max_error: float = 0.1,
         allow_unstable: Union[float, bool] = 0.1,
-        exclude_polyanions: Sequence[str] = (
+        exclude_polyanions: List[str] = [
             "SO4",
+            "SO3",
             "CO3",
             "NO3",
+            "NO2",
             "OCl3",
-            "SiO4",
+            "ClO3",
+            "ClO4",
+            "HO",
+            "ClO",
             "SeO3",
             "TiO3",
             "TiO4",
-        ),
+            "WO4",
+            "SiO3",
+            "SiO4",
+            "Si2O5",
+            "PO3",
+            "PO4",
+            "P2O7",
+        ],
     ) -> None:
         """
         Initializes a CorrectionCalculator.
@@ -178,9 +184,7 @@ class CorrectionCalculator:
 
             compound = self.calc_compounds.get(name, None)
             if not compound:
-                warnings.warn(
-                    "Compound {} is not found in provided computed entries and is excluded from the fit".format(name)
-                )
+                warnings.warn(f"Compound {name} is not found in provided computed entries and is excluded from the fit")
                 continue
 
             # filter out compounds with large uncertainties
@@ -197,9 +201,7 @@ class CorrectionCalculator:
             for anion in self.exclude_polyanions:
                 if anion in name or anion in cmpd_info["formula"]:
                     allow = False
-                    warnings.warn(
-                        "Compound {} contains the polyanion {} and is excluded from the fit".format(name, anion)
-                    )
+                    warnings.warn(f"Compound {name} contains the polyanion {anion} and is excluded from the fit")
                     break
 
             # filter out compounds that are unstable
@@ -210,9 +212,7 @@ class CorrectionCalculator:
                     raise ValueError("Missing e above hull data")
                 if eah > self.allow_unstable:
                     allow = False
-                    warnings.warn(
-                        "Compound {} is unstable and excluded from the fit (e_above_hull = {})".format(name, eah)
-                    )
+                    warnings.warn(f"Compound {name} is unstable and excluded from the fit (e_above_hull = {eah})")
 
             if allow:
                 comp = Composition(name)
@@ -268,7 +268,7 @@ class CorrectionCalculator:
                         try:
                             coeff.append(comp[specie])
                         except ValueError:
-                            raise ValueError("We can't detect this specie: {}".format(specie))
+                            raise ValueError(f"We can't detect this specie: {specie}")
 
                 self.names.append(name)
                 self.diffs.append((cmpd_info["exp energy"] - energy) / comp.num_atoms)
@@ -301,11 +301,16 @@ class CorrectionCalculator:
             )
         self.corrections = popt.tolist()
         self.corrections_std_error = np.sqrt(np.diag(self.pcov)).tolist()
-        for i in range(len(self.species)):
-            self.corrections_dict[self.species[i]] = (
+        for i, v in enumerate(self.species):
+            self.corrections_dict[v] = (
                 round(self.corrections[i], 3),
                 round(self.corrections_std_error[i], 4),
             )
+
+        # set ozonide correction to 0 so that this species does not receive a correction
+        # while other oxide types do
+        self.corrections_dict["ozonide"] = (0, 0)
+
         return self.corrections_dict
 
     def graph_residual_error(self) -> go.Figure:
@@ -414,14 +419,16 @@ class CorrectionCalculator:
 
         return fig
 
-    def make_yaml(self, name: str = "MP2020") -> None:
+    def make_yaml(self, name: str = "MP2020", dir: Optional[str] = None) -> None:
         """
         Creates the _name_Compatibility.yaml that stores corrections as well as _name_CompatibilityUncertainties.yaml
         for correction uncertainties.
 
         Args:
             name: str, alternate name for the created .yaml file.
-            Default: "MP2020"
+                Default: "MP2020"
+            dir: str, directory in which to save the file. Pass None (default) to
+                save the file in the current working directory.
         """
 
         if len(self.corrections) == 0:
@@ -430,15 +437,15 @@ class CorrectionCalculator:
         # elements with U values
         ggaucorrection_species = ["V", "Cr", "Mn", "Fe", "Co", "Ni", "W", "Mo"]
 
-        comp_corr: "OrderedDict[str, float]" = OrderedDict()
-        o: "OrderedDict[str, float]" = OrderedDict()
-        f: "OrderedDict[str, float]" = OrderedDict()
+        comp_corr: Dict[str, float] = {}
+        o: Dict[str, float] = {}
+        f: Dict[str, float] = {}
 
-        comp_corr_error: "OrderedDict[str, float]" = OrderedDict()
-        o_error: "OrderedDict[str, float]" = OrderedDict()
-        f_error: "OrderedDict[str, float]" = OrderedDict()
+        comp_corr_error: Dict[str, float] = {}
+        o_error: Dict[str, float] = {}
+        f_error: Dict[str, float] = {}
 
-        for specie in self.species:
+        for specie in list(self.species) + ["ozonide"]:
             if specie in ggaucorrection_species:
                 o[specie] = self.corrections_dict[specie][0]
                 f[specie] = self.corrections_dict[specie][0]
@@ -450,9 +457,6 @@ class CorrectionCalculator:
                 comp_corr[specie] = self.corrections_dict[specie][0]
                 comp_corr_error[specie] = self.corrections_dict[specie][1]
 
-        comp_corr["ozonide"] = 0  # do i need this??
-        comp_corr_error["ozonide"] = 0
-
         outline = """\
         Name:
         Corrections:
@@ -466,11 +470,13 @@ class CorrectionCalculator:
                 F:
             CompositionCorrections:
         """
-
         fn = name + "Compatibility.yaml"
-        file = open(fn, "w")
+        if dir:
+            path = os.path.join(dir, fn)
+        else:
+            path = fn
+
         yml = yaml.YAML()
-        yml.Representer.add_representer(OrderedDict, yml.Representer.represent_dict)
         yml.default_flow_style = False
         contents = yml.load(outline)
 
@@ -497,6 +503,5 @@ class CorrectionCalculator:
         contents["Uncertainties"].yaml_set_start_comment(
             "Uncertainties corresponding to each energy correction (eV/atom)", indent=2
         )
-
-        yaml.dump(contents, file)
-        file.close()
+        with open(path, "w") as file:
+            yml.dump(contents, file)
