@@ -6,18 +6,18 @@ import logging
 import sys
 from collections import namedtuple
 from os.path import join
-from typing import Dict, List, Optional, Union, Set
+from typing import Dict, List, Optional, Set, Union
 from urllib.parse import urlparse
 
 import requests
 from tqdm import tqdm
 
-# from retrying import retry
-
 from pymatgen.core.periodic_table import DummySpecies
 from pymatgen.core.structure import Structure
 from pymatgen.util.provenance import StructureNL
 
+# from retrying import retry
+
 
 # TODO: importing optimade-python-tool's data structures will make more sense
 Provider = namedtuple("Provider", ["name", "base_url", "description", "homepage", "prefix"])
