@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 #
@@ -17,7 +16,7 @@ from monty.collections import AttrDict
 from monty.design_patterns import singleton
 from monty.json import MontyDecoder, MontyEncoder, MSONable
 
-import pymatgen.core.units as units
+from pymatgen.core import units
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.core.units import ArrayWithUnit
@@ -57,9 +56,9 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
         angdeg = np.reshape(angdeg, 3)
 
         if np.any(angdeg <= 0.0):
-            raise ValueError("Angles must be > 0 but got %s" % str(angdeg))
+            raise ValueError(f"Angles must be > 0 but got {str(angdeg)}")
         if angdeg.sum() >= 360.0:
-            raise ValueError("The sum of angdeg must be lower that 360, angdeg %s" % str(angdeg))
+            raise ValueError(f"The sum of angdeg must be lower that 360, angdeg {str(angdeg)}")
 
         # This code follows the implementation in ingeo.F90
         # See also http://www.abinit.org/doc/helpfiles/for-v7.8/input_variables/varbas.html#angdeg
@@ -99,7 +98,7 @@ def lattice_from_abivars(cls=None, *args, **kwargs):
         rprimd = [float(acell[i]) * rprim[i] for i in range(3)]
         return cls(ArrayWithUnit(rprimd, "bohr").to("ang"))
 
-    raise ValueError("Don't know how to construct a Lattice from dict:\n%s" % pformat(d))
+    raise ValueError(f"Don't know how to construct a Lattice from dict:\n{pformat(d)}")
 
 
 def structure_from_abivars(cls=None, *args, **kwargs):
@@ -144,7 +143,7 @@ def structure_from_abivars(cls=None, *args, **kwargs):
         coords_are_cartesian = True
 
     if coords is None:
-        raise ValueError("Cannot extract coordinates from:\n %s" % str(d))
+        raise ValueError(f"Cannot extract coordinates from:\n {str(d)}")
 
     coords = np.reshape(coords, (-1, 3))
 
@@ -157,10 +156,10 @@ def structure_from_abivars(cls=None, *args, **kwargs):
         typat = [typat]
 
     if len(typat) != len(coords):
-        raise ValueError("len(typat) != len(coords):\ntypat: %s\ncoords: %s" % (typat, coords))
+        raise ValueError(f"len(typat) != len(coords):\ntypat: {typat}\ncoords: {coords}")
 
     # Note conversion to int and Fortran --> C indexing
-    typat = np.array(typat, dtype=np.int_)
+    typat = np.array(typat, dtype=int)
     species = [znucl_type[typ - 1] for typ in typat]
 
     return cls(
@@ -245,7 +244,7 @@ or the Virtual Crystal Approximation."""
 
         # [ntypat] list
         znucl_type = [specie.number for specie in types_of_specie]
-        typat = np.zeros(natom, np.int_)
+        typat = np.zeros(natom, int)
         for atm_idx, site in enumerate(structure):
             typat[atm_idx] = types_of_specie.index(site.specie) + 1
     else:
@@ -294,7 +293,7 @@ or the Virtual Crystal Approximation."""
             angdeg=angdeg,
         )
     else:
-        raise ValueError("Wrong value for geomode: %s" % geomode)
+        raise ValueError(f"Wrong value for geomode: {geomode}")
 
     return d
 
@@ -318,7 +317,7 @@ def contract(s):
             old = t
             count.append([1, t])
 
-    return " ".join("%d*%s" % (c, t) for c, t in count)
+    return " ".join(f"{c}*{t}" for c, t in count)
 
 
 class AbivarAble(metaclass=abc.ABCMeta):
@@ -386,7 +385,7 @@ class SpinMode(
         try:
             return _mode2spinvars[obj]
         except KeyError:
-            raise KeyError("Wrong value for spin_mode: %s" % str(obj))
+            raise KeyError(f"Wrong value for spin_mode: {str(obj)}")
 
     def to_abivars(self):
         """Dictionary with Abinit input variables."""
@@ -419,7 +418,7 @@ _mode2spinvars = {
 
 class Smearing(AbivarAble, MSONable):
     """
-    Variables defining the smearing technique. The preferred way to instanciate
+    Variables defining the smearing technique. The preferred way to instantiate
     a `Smearing` object is via the class method Smearing.as_smearing(string)
     """
 
@@ -439,9 +438,9 @@ class Smearing(AbivarAble, MSONable):
         self.tsmear = tsmear
 
     def __str__(self):
-        s = "occopt %d # %s Smearing\n" % (self.occopt, self.mode)
+        s = f"occopt {self.occopt} # {self.mode} Smearing\n"
         if self.tsmear:
-            s += "tsmear %s" % self.tsmear
+            s += f"tsmear {self.tsmear}"
         return s
 
     def __eq__(self, other):
@@ -494,7 +493,7 @@ class Smearing(AbivarAble, MSONable):
         for (mode_str, occopt) in self._mode2occopt.items():
             if occopt == self.occopt:
                 return mode_str
-        raise AttributeError("Unknown occopt %s" % self.occopt)
+        raise AttributeError(f"Unknown occopt {self.occopt}")
 
     @staticmethod
     def nosmearing():
@@ -541,7 +540,7 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
 
         for k in self:
             if k not in self._DEFAULT:
-                raise ValueError("%s: No default value has been provided for " "key %s" % (self.__class__.__name__, k))
+                raise ValueError(f"{self.__class__.__name__}: No default value has been provided for key {k}")
 
     def to_abivars(self):
         """Dictionary with Abinit input variables."""
@@ -788,7 +787,7 @@ class KSampling(AbivarAble, MSONable):
             )
 
         else:
-            raise ValueError("Unknown mode %s" % mode)
+            raise ValueError(f"Unknown mode {mode}")
 
         self.abivars = abivars
         # self.abivars["#comment"] = comment
@@ -980,7 +979,7 @@ class KSampling(AbivarAble, MSONable):
         # ensure that num_div[i] > 0
         num_div = [i if i > 0 else 1 for i in num_div]
 
-        comment = "pymatge.io.abinit generated KPOINTS with grid density = " + "{} / atom".format(kppa)
+        comment = "pymatge.io.abinit generated KPOINTS with grid density = " + f"{kppa} / atom"
 
         return cls(
             mode="monkhorst",
@@ -1071,12 +1070,12 @@ class RelaxationMethod(AbivarAble, MSONable):
 
         for k in self.abivars:
             if k not in self._default_vars:
-                raise ValueError("%s: No default value has been provided for key %s" % (self.__class__.__name__, k))
+                raise ValueError(f"{self.__class__.__name__}: No default value has been provided for key {k}")
 
         for k in self.abivars:
             if k is MANDATORY:
                 raise ValueError(
-                    "%s: No default value has been provided for the mandatory key %s" % (self.__class__.__name__, k)
+                    f"{self.__class__.__name__}: No default value has been provided for the mandatory key {k}"
                 )
 
     @classmethod
@@ -1160,7 +1159,7 @@ class RelaxationMethod(AbivarAble, MSONable):
 
 
 class PPModelModes(Enum):
-    """Differnt kind of plasmon-pole models."""
+    """Different kind of plasmon-pole models."""
 
     noppmodel = 0
     godby = 1
@@ -1172,7 +1171,7 @@ class PPModelModes(Enum):
 class PPModel(AbivarAble, MSONable):
     """
     Parameters defining the plasmon-pole technique.
-    The common way to instanciate a PPModel object is via the class method PPModel.as_ppmodel(string)
+    The common way to instantiate a PPModel object is via the class method PPModel.as_ppmodel(string)
     """
 
     @classmethod
@@ -1233,11 +1232,7 @@ class PPModel(AbivarAble, MSONable):
     __nonzero__ = __bool__
 
     def __repr__(self):
-        return "<%s at %s, mode = %s>" % (
-            self.__class__.__name__,
-            id(self),
-            str(self.mode),
-        )
+        return f"<{self.__class__.__name__} at {id(self)}, mode = {str(self.mode)}>"
 
     def to_abivars(self):
         """Return dictionary with Abinit variables."""
@@ -1286,7 +1281,7 @@ class HilbertTransform(AbivarAble):
         Args:
             nomegasf: Number of points for sampling the spectral function along the real axis.
             domegasf: Step in Ha for the linear mesh used for the spectral function.
-            spmeth: Algorith for the representation of the delta function.
+            spmeth: Algorithm for the representation of the delta function.
             nfreqre: Number of points along the real axis (linear mesh).
             freqremax: Maximum frequency for W along the real axis (in hartree).
             nfreqim: Number of point along the imaginary axis (Gauss-Legendre mesh).
@@ -1377,10 +1372,10 @@ class Screening(AbivarAble):
             inclvkb: Option for the treatment of the dipole matrix elements (NC pseudos).
         """
         if w_type not in self._WTYPES:
-            raise ValueError("W_TYPE: %s is not supported" % w_type)
+            raise ValueError(f"W_TYPE: {w_type} is not supported")
 
         if sc_mode not in self._SC_MODES:
-            raise ValueError("Self-consistecy mode %s is not supported" % sc_mode)
+            raise ValueError(f"Self-consistecy mode {sc_mode} is not supported")
 
         self.ecuteps = ecuteps
         self.nband = nband
@@ -1483,10 +1478,10 @@ class SelfEnergy(AbivarAble):
             ecutwfn: Cutoff energy for the wavefunctions (Default: ecutwfn == ecut).
         """
         if se_type not in self._SIGMA_TYPES:
-            raise ValueError("SIGMA_TYPE: %s is not supported" % se_type)
+            raise ValueError(f"SIGMA_TYPE: {se_type} is not supported")
 
         if sc_mode not in self._SC_MODES:
-            raise ValueError("Self-consistecy mode %s is not supported" % sc_mode)
+            raise ValueError(f"Self-consistecy mode {sc_mode} is not supported")
 
         self.type = se_type
         self.sc_mode = sc_mode
@@ -1658,9 +1653,9 @@ class ExcHamiltonian(AbivarAble):
 
         # Consistency check
         if any(bs_loband < 0):
-            raise ValueError("bs_loband <= 0 while it is %s" % bs_loband)
+            raise ValueError(f"bs_loband <= 0 while it is {bs_loband}")
         if any(bs_loband >= nband):
-            raise ValueError("bs_loband (%s) >= nband (%s)" % (bs_loband, nband))
+            raise ValueError(f"bs_loband ({bs_loband}) >= nband ({nband})")
 
     @property
     def inclvkb(self):
@@ -1716,7 +1711,7 @@ class ExcHamiltonian(AbivarAble):
             raise NotImplementedError("")
 
         else:
-            raise ValueError("Unknown algorithm for EXC: %s" % self.algo)
+            raise ValueError(f"Unknown algorithm for EXC: {self.algo}")
 
         # Add extra kwargs
         abivars.update(self.kwargs)
