@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Pymatgen Development Team.
 # Distributed under the terms of the MIT License.
 
@@ -62,13 +61,13 @@ class SymmetrizedStructure(Structure):
         self.equivalent_indices: List[int] = equivalent_indices  # type: ignore
         self.equivalent_sites: List[PeriodicSite] = equivalent_sites  # type: ignore
         self.wyckoff_letters = wyckoff_letters
-        self.wyckoff_symbols = ["%d%s" % (len(w), w[0]) for w in wyckoff_symbols]
+        self.wyckoff_symbols = [f"{len(w)}{w[0]}" for w in wyckoff_symbols]
 
     def copy(self):
         """
         :return: Copy of structure.
         """
-        return self.__class__(
+        return SymmetrizedStructure(
             self,
             spacegroup=self.spacegroup,
             equivalent_positions=self.site_labels,
@@ -97,21 +96,22 @@ class SymmetrizedStructure(Structure):
     def __str__(self):
         outs = [
             "SymmetrizedStructure",
-            "Full Formula ({s})".format(s=self.composition.formula),
-            "Reduced Formula: {}".format(self.composition.reduced_formula),
+            f"Full Formula ({self.composition.formula})",
+            f"Reduced Formula: {self.composition.reduced_formula}",
+            f"Spacegroup: {self.spacegroup.int_symbol} ({self.spacegroup.int_number})",
         ]
 
         def to_s(x):
-            return "%0.6f" % x
+            return f"{x:0.6f}"
 
         outs.append("abc   : " + " ".join([to_s(i).rjust(10) for i in self.lattice.abc]))
         outs.append("angles: " + " ".join([to_s(i).rjust(10) for i in self.lattice.angles]))
         if self._charge:
             if self._charge >= 0:
-                outs.append("Overall Charge: +{}".format(self._charge))
+                outs.append(f"Overall Charge: +{self._charge}")
             else:
-                outs.append("Overall Charge: -{}".format(self._charge))
-        outs.append("Sites ({i})".format(i=len(self)))
+                outs.append(f"Overall Charge: -{self._charge}")
+        outs.append(f"Sites ({len(self)})")
         data = []
         props = self.site_properties
         keys = sorted(props.keys())
